

import time, sys
import pydfb as pygame

# ----------------------------------------------------------------------------
def validateTest( i, refs, curref ):
  if refs!= curref:
    s= 'FAILED'
  else:
    s= 'PASSED'
  print '%d iterations completed.\nExpected to see refcount=%d. See %d.\n-------------------------Test %s' % ( i+1, refs, curref, s )
  return s

# ----------------------------------------------------------------------------
# Verify we have no leaks in screen handling
def test_screen():
  print 'test_screen'
  modes= ( (640,480), (800,600), (1024,768) )
  for i in xrange( 20 ):
    mode= modes[ i % len( modes ) ]
    pygame.display.set_mode( mode, 0, 32 )
    time.sleep( 1 )
    if i== 0:
      refs= sys.gettotalrefcount()
    print 'Iteration %d: %d' % ( i, sys.gettotalrefcount() )
  
  curref= sys.gettotalrefcount()
  return validateTest( i, refs, curref )

# ----------------------------------------------------------------------------
# Verify we have no leaks in draw
def test_draw():
  print 'test_draw'
  screen= pygame.display.set_mode( (800,600), 0, 32 )
  for i in xrange( 20 ):
    screen.fill( (0,0,0) )
    pygame.draw.aalines( screen, (230, 80, 220), 1, ( ( 40+ i, 250 ), ( 60+ i, 270 ), ( 90+ i, 400 ), ( 80+ i, 450 ), ( 60+ i, 320 ), ( 35+ i, 280 ) ) )
    pygame.draw.arc( screen, (230, 180, 190), ( 200, 200, 200, 150+ i ), 0, 3.14 )
    pygame.draw.ellipse( screen, (230, 180, 190), ( 200, 200, 200, 150+ i ) )
    pygame.draw.circle( screen, (230, 180, 190), (200+i,300), 80 )
    pygame.draw.polygon( screen, (200, 160, 134 ), ( ( 40+ i, 250 ), ( 60+ i, 270 ), ( 90+ i, 400 ), ( 80+ i, 450 ), ( 60+ i, 320 ), ( 35+ i, 280 ) ) )
    if i== 0:
      refs= sys.gettotalrefcount()
    print 'Iteration %d: %d' % ( i, sys.gettotalrefcount() )

  curref= sys.gettotalrefcount()
  return validateTest( i, refs, curref )

# ----------------------------------------------------------------------------
# Verify we have no leaks in surface creating/destroying
def test_surface():
  print 'test_surface'
  screen= pygame.display.set_mode( (800,600), 0, 32 )
  for i in xrange( 20 ):
    s= pygame.Surface( (400,400), 0, 32 )
    if i== 0:
      refs= sys.gettotalrefcount()
    print 'Iteration %d: %d' % ( i, sys.gettotalrefcount() )

  curref= sys.gettotalrefcount()
  return validateTest( i, refs, curref )


# ----------------------------------------------------------------------------
# Verify we have no leaks in image creating/rendering
def test_image():
  print 'test_image'
  screen= pygame.display.set_mode( (800,600), 0, 32 )
  for i in xrange( 20 ):
    screen.fill( (0,0,0) )
    i1= pygame.image.load( 'data/alpha.png' )
    screen.blit( i1, (0,0))
    i2= pygame.image.load( 'data/transp.gif' )
    screen.blit( i2, (i1.get_width(),0))
    i3= pygame.image.load( 'data/bg.jpg' )
    screen.blit( i3, (0,i2.get_height()))
    time.sleep( 0.5 )
    if i== 0:
      refs= sys.gettotalrefcount()
    print 'Iteration %d: %d' % ( i, sys.gettotalrefcount() )

  curref= sys.gettotalrefcount()
  return validateTest( i, refs, curref )

# ----------------------------------------------------------------------------
# Verify we have no leaks in font creating/rendering
def test_font():
  print 'test_font'
  screen= pygame.display.set_mode( (800,600), 0, 32 )
  for i in xrange( 20 ):
    screen.fill( (0,0,0) )
    f= pygame.font.Font( 'data/arialn.ttf', 80 )
    s= f.render( 'Leak test goes on and on', 1, (230,130,160))
    screen.blit( s, (0,0))
    time.sleep( 0.5 )
    if i== 0:
      refs= sys.gettotalrefcount()
    print 'Iteration %d: %d' % ( i, sys.gettotalrefcount() )

  curref= sys.gettotalrefcount()
  return validateTest( i, refs, curref )

# ----------------------------------------------------------------------------
# Verify we have no leaks in overlay creating/rendering
def test_overlay():
  import pickle
  print 'test_overlay'
  WH= (720,400)
  screen= pygame.display.set_mode( (800,600), 0, 32 )
  for i in xrange( 20 ):
    overlay= pygame.Overlay( pygame.PF_YV12, WH )
    f= open( 'dump/yuv_%d' % (i+1), 'r' )
    data= pickle.load( f )
    f.close()
    overlay.display( data )
    time.sleep( 1 )
    if i== 0:
      refs= sys.gettotalrefcount()
    print 'Iteration %d: %d' % ( i, sys.gettotalrefcount() )

  curref= sys.gettotalrefcount()
  return validateTest( i, refs, curref )

# ----------------------------------------------------------------------------
# Verify we have no leaks in event handling


pygame.init()
"""
res= test_screen()

# We should allow to test until we fail for the first time
# Mainly because of functionality that fails may be used in later tests
if res== 'PASSED':
  res= test_draw()
if res== 'PASSED':
  res= test_surface()
if res== 'PASSED':
  res= test_image()
if res== 'PASSED':
  res= test_font()
if res== 'PASSED':
"""
res= test_overlay()

pygame.quit()
